pub struct Selector<'a, T: Serialize + for<'de> Deserialize<'de>> {
inner: SelectorInner<'a, T>,
}Expand description
Borrows of a GenericReceiverSet used to drive repeated select calls
without rebuilding the underlying crossbeam_channel::Select each time.
See GenericReceiverSet::selector.
Fields
inner: SelectorInner<'a, T>Implementations
Sourceimpl<'a, T: Serialize + for<'de> Deserialize<'de>> Selector<'a, T>
impl<'a, T: Serialize + for<'de> Deserialize<'de>> Selector<'a, T>
Sourcepub fn select(&mut self) -> Vec<GenericSelectionResult<T>>
pub fn select(&mut self) -> Vec<GenericSelectionResult<T>>
Block until at least one of the Receivers receives a message.
Note: The IPC variant can return multiple results in one call. The crossbeam variant always returns exactly one.